# fastbook libraries
> Simple installer for everything needed for fastbook

## Installing

To install everything needed for the fastbook, you can run:
``` 
conda install -c fastai fastai2 graphviz
pip install fastbook
```

